func GetCombinations(cards []Card, k int) [][]Card
GetCombinations returns all unordered combinations of size k from the given cards
Optimization note: returning a flat slice makes the (52 choose 7) benchmark considerably faster, but not
sure we care right now
Card is a card
This is a 64 bit int because that's what we're going to use everywhere, but a card is guaranteed to use
only the lowest 8 bits
Guaranteed not to be 0
const (
// Two is two Two Rank = iota + 1
// Three is three Three
// Four is four Four
// Five is five Five
// Six is six Six
// Seven is seven Seven
// Eight is eight Eight
// Nine is nine Nine
// Ten is ten Ten
// Jack is jack Jack
// Queen is queen Queen
// King is king King
// Ace is ace Ace
)