Documentation
¶
Index ¶
- func GetCurrentOrder(hole []base.Card, board []base.Card) ([][][]base.Card, int64, int64, int64, int64, error)
- func GetFutureOutcomes(hole []base.Card, board []base.Card) (float64, float64, float64, error)
- func GetInitialOutcomes(hole []base.Card) (float64, float64, float64, error)
- func PrecomputeInitialOutcomes() error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetCurrentOrder ¶
func GetCurrentOrder(hole []base.Card, board []base.Card) ([][][]base.Card, int64, int64, int64, int64, error)
GetCurrentOrder returns, given a board of 3 to 5 cards, all other possible coexisting holes sorted into levels from best to worst, where holes in better levels will beat holes in worse levels and holes in the same level will tie, assuming no other cards are dealt to the board, as well as the rank of this hole relative to the ordering. TODO: add number of opponents
func GetFutureOutcomes ¶
GetFutureOutcomes returns, given a hole and board of 3 to 5 cards, the probability that the hole will win, tie, and lose at the end of the game, assumming random subsequent cards. TODO: add number of opponents
func GetInitialOutcomes ¶
GetInitialOutcomes returns, given a hole and empty board, the probability that the hole will win, tie, and lose at the end of the game, assumming random subsequent cards. i.e. the starting hand probabilities, which are always the same. TODO: add number of opponents
func PrecomputeInitialOutcomes ¶
func PrecomputeInitialOutcomes() error
PrecomputeInitialOutcomes precomputes the initial outcomes and stores them in a file for GetInitialOutcomes to later use.
Types ¶
This section is empty.